@@ -268,7 +268,7 @@ gnome_icon_theme_init (GnomeIconTheme *icon_theme)
   icon_theme->priv = priv;
 
   priv->custom_theme = FALSE;
-  priv->current_theme = g_strdup ("default");
+  priv->current_theme = g_strdup ("hicolor");
   priv->search_path = g_new (char *, 5);
   
 
@@ -635,8 +635,9 @@ load_themes (GnomeIconTheme *icon_theme)
   priv->all_icons = g_hash_table_new (g_str_hash, g_str_equal);
   
   insert_theme (icon_theme, priv->current_theme);
+  
   /* Always look in the "default" icon theme */
-  insert_theme (icon_theme, "default");
+  insert_theme (icon_theme, "hicolor");
   priv->themes = g_list_reverse (priv->themes);
   
   priv->unthemed_icons = g_hash_table_new_full (g_str_hash, g_str_equal,
@@ -674,15 +675,20 @@ load_themes (GnomeIconTheme *icon_theme)
 		    g_hash_table_replace (priv->unthemed_icons,
 					  base_name,
 					  abs_file);
-
+		  else
+		    {
+		      g_free (base_name);
+		      g_free (abs_file);
+		    }
 		}
 	      else
-		g_hash_table_insert (priv->unthemed_icons,
-				     base_name,
-				     abs_file);
-	      
-	      g_hash_table_insert (priv->all_icons,
-				   base_name, NULL);
+		{
+		  g_hash_table_insert (priv->unthemed_icons,
+				       base_name,
+				       abs_file);
+		  g_hash_table_insert (priv->all_icons,
+				       base_name, NULL);
+		}
 	    }
 	}
       g_dir_close (gdir);
@@ -1268,8 +1274,10 @@ theme_subdir_load (GnomeIconTheme *icon_theme,
 	type = ICON_THEME_DIR_SCALABLE;
       else if (strcmp (type_string, "Threshold") == 0)
 	type = ICON_THEME_DIR_THRESHOLD;
-    }
 
+      g_free (type_string);
+    }
+  
   context = 0;
   if (gnome_theme_file_get_string (theme_file, subdir, "Context", &context_string))
     {
